==> sagua_0.2.3-1.tar.gz: sagua-0.2.3/src/imagebutton.cc <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mod: nil; c-basic-offset: 4 -*- */
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file imagebutton.cc
/// @brief Class for rollover image button source file.

#include "../include/imagebutton.h"

/// @brief Constructor of ImageButton.
/// @param normal Button normal image file path.
/// @param over Button over image file path.
/// @param press Button press image file path.
ImageButton::ImageButton(const std::string& normal, const std::string& over, const std::string& press)
    : normalImage_(Gdk::Pixbuf::create_from_file(normal)),
      overImage_(Gdk::Pixbuf::create_from_file(over)),
      pressImage_(Gdk::Pixbuf::create_from_file(press)),
      prevImage_(normalImage_)
{
    set_size_request(normalImage_->get_width(), normalImage_->get_height());

    add(drawingArea_);
  
    set_events(Gdk::ENTER_NOTIFY_MASK | Gdk::LEAVE_NOTIFY_MASK | Gdk::BUTTON_PRESS_MASK | Gdk::BUTTON_RELEASE_MASK);    

    signal_enter_notify_event().connect(sigc::mem_fun(*this, &ImageButton::OnEnterNotify) ); 
    signal_leave_notify_event().connect(sigc::mem_fun(*this, &ImageButton::OnLeaveNotify) );
    signal_button_press_event().connect(sigc::mem_fun(*this, &ImageButton::OnBtnPress) );
    signal_button_release_event().connect(sigc::mem_fun(*this, &ImageButton::OnBtnRelease) );	

    drawingArea_.signal_expose_event().connect(sigc::mem_fun(*this, &ImageButton::OnExposeEvent) );
}

ImageButton::~ImageButton()
{}

/// @brief You need to connect this signal to detect button is pressed.
sigc::signal<void> ImageButton::SignalPress()
{
    return signalPress_;
}

/// @brief Callback function when button is pressed.
///
/// If pressed button is 1 button, hide previous image and display pressImage.
/// And transmit signal to connected to signalPress. 
bool ImageButton::OnBtnPress(GdkEventButton* ev)
{
    if( (ev->type == GDK_BUTTON_PRESS) && (ev->button == 1) ) {

	Render(pressImage_);
	
	prevImage_ = pressImage_;

	signalPress_.emit();

    }

    return false;
}

/// @brief Callback function when button is released.
bool ImageButton::OnBtnRelease(GdkEventButton* ev)
{
    Render(overImage_);

    prevImage_ = overImage_;

    return false;
}

/// @brief Callback function when button is entered notify.
bool ImageButton::OnEnterNotify(GdkEventCrossing* ev)
{
    Render(overImage_);
    
    prevImage_ = overImage_;

    return false;
}

/// @brief Callback function when button is leaved notify.
bool ImageButton::OnLeaveNotify(GdkEventCrossing* ev)
{
    Render(normalImage_);
    
    prevImage_ = normalImage_;
    
    return false;
}

/// @brief Callback function when drawing area is received expose event.
bool ImageButton::OnExposeEvent(GdkEventExpose* ev)
{
    Render(prevImage_);

    return true;
}

==> sagua_0.2.4-1.tar.gz: sagua-0.2.4/src/imagebutton.cc <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mod: nil; c-basic-offset: 4 -*- */
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file imagebutton.cc
/// @brief Class for rollover image button source file.

#include "../include/imagebutton.h"

/// @brief Constructor of ImageButton.
/// @param normal Button normal image file path.
/// @param over Button over image file path.
/// @param press Button press image file path.
ImageButton::ImageButton(const char* const normal, const char* const over, const char* const press)
    : normalImage_(Gdk::Pixbuf::create_from_file(normal)),
      overImage_(Gdk::Pixbuf::create_from_file(over)),
      pressImage_(Gdk::Pixbuf::create_from_file(press)),
      prevImage_(normalImage_)
{
    set_size_request(normalImage_->get_width(), normalImage_->get_height());

    add(drawingArea_);

    set_events(Gdk::ENTER_NOTIFY_MASK | Gdk::LEAVE_NOTIFY_MASK | Gdk::BUTTON_PRESS_MASK | Gdk::BUTTON_RELEASE_MASK);    

    drawingArea_.signal_expose_event().connect(sigc::mem_fun(*this, &ImageButton::OnExposeEvent) );
}

/// @brief Callback function when button is pressed.
///
/// If pressed button is 1 button, hide previous image and display pressImage.
/// And transmit signal to connected to signalPress. 
bool ImageButton::on_button_press_event(GdkEventButton* ev)
{
    if( (ev->type == GDK_BUTTON_PRESS) && (ev->button == 1) ) {

        ShowImage(pressImage_);

        signalPress_.emit();

    }

    return false;
}

/// @brief Callback function when button is released.
bool ImageButton::on_button_release_event(GdkEventButton* ev)
{
    ShowImage(overImage_);

    return false;
}

/// @brief Callback function when button is entered notify.
bool ImageButton::on_enter_notify_event(GdkEventCrossing* ev)
{
    ShowImage(overImage_);

    return false;
}

/// @brief Callback function when button is leaved notify.
bool ImageButton::on_leave_notify_event(GdkEventCrossing* ev)
{
    ShowImage(normalImage_);
    
    return false;
}

/// @brief Callback function when drawing area is received expose event.
bool ImageButton::OnExposeEvent(GdkEventExpose* ev)
{
    Render(prevImage_);

    return true;
}
